@@ -28,7 +28,6 @@
 #include "interface.h"
 #include "proctable.h"
 #include "util.h"
-#include "infoview.h"
 #include "procactions.h"
 #include "procdialogs.h"
 #include "memmaps.h"
@@ -145,21 +144,21 @@ cb_hide_process (GtkAction *action, gpointer data)
 void
 cb_about (GtkAction *action, gpointer data)
 {
-	static const gchar *authors[] = {
+	const gchar * const authors[] = {
 		"Kevin Vandersloot",
-		N_("Jorgen Scheibengruber - nicer devices treeview"),
-		N_("Benoît Dejean - maintainer"),
+		"Erik Johnsson",
+		"Jorgen Scheibengruber",
+		"Benoît Dejean",
+		"Paollo Borelli",
 		NULL
 	};
 
-	static const gchar * const documenters[] = {
+	const gchar * const documenters[] = {
 		"Bill Day",
 		"Sun Microsystems",
 		NULL
 	};
 
-	PROCMAN_GETTEXT_ARRAY_INIT(authors);
-
 	gtk_show_about_dialog (
 		NULL,
 		"name",			_("System Monitor"),
@@ -323,9 +322,6 @@ cb_row_selected (GtkTreeSelection *selection, gpointer data)
 					     &procdata->selected_process);
 
 	if (procdata->selected_process) {
-		if (procdata->config.show_more_info)
-			infoview_update (procdata);
-
 		update_sensitivity (procdata, TRUE);
 	}
 	else {
